@@ -4,18 +4,17 @@
 #  All rights reserved.
 #
 import logging
+import re
+
 import pandas as pd
 import redis
 from pytablewriter import MarkdownTableWriter
 import humanize
 import datetime as dt
-
+from tqdm import tqdm
 from redisbench_admin.utils.remote import get_overall_dashboard_keynames
 
 
-from redisbench_admin.utils.utils import get_ts_metric_name
-
-
 def compare_command_logic(args, project_name, project_version):
     logging.info(
         "Using: {project_name} {project_version}".format(
@@ -40,16 +39,27 @@ def compare_command_logic(args, project_name, project_version):
     tf_github_org = args.github_org
     tf_github_repo = args.github_repo
     tf_triggering_env = args.triggering_env
-    deployment_type = args.deployment_type
-    deployment_name = args.deployment_name
+    if args.baseline_deployment_name != "":
+        baseline_deployment_name = args.baseline_deployment_name
+    else:
+        baseline_deployment_name = args.deployment_name
+    if args.comparison_deployment_name != "":
+        comparison_deployment_name = args.comparison_deployment_name
+    else:
+        comparison_deployment_name = args.deployment_name
+
     logging.info(
-        "Using deployment_type={} and deployment_name={} for the analysis".format(
-            deployment_type,
-            deployment_name,
+        "Using baseline deployment_name={} and comparison deployment_name={} for the analysis".format(
+            baseline_deployment_name,
+            comparison_deployment_name,
         )
     )
     from_ts_ms = args.from_timestamp
     to_ts_ms = args.to_timestamp
+    if from_ts_ms is None:
+        from_ts_ms = int(args.from_date.timestamp() * 1000)
+    if to_ts_ms is None:
+        to_ts_ms = int(args.to_date.timestamp() * 1000)
     from_human_str = humanize.naturaltime(
         dt.datetime.utcfromtimestamp(from_ts_ms / 1000)
     )
@@ -94,12 +104,13 @@ def compare_command_logic(args, project_name, project_version):
     (
         prefix,
         testcases_setname,
+        _,
         tsname_project_total_failures,
         tsname_project_total_success,
         _,
         _,
         _,
-        _,
+        testcases_metric_context_path_setname,
         _,
         _,
         _,
@@ -107,54 +118,95 @@ def compare_command_logic(args, project_name, project_version):
         _,
     ) = get_overall_dashboard_keynames(tf_github_org, tf_github_repo, tf_triggering_env)
     test_names = []
-    try:
-        test_names = rts.smembers(testcases_setname)
-        test_names = list(test_names)
-        test_names.sort()
-    except redis.exceptions.ResponseError as e:
+    used_key = testcases_setname
+    test_filter = "test_name"
+
+    if args.use_metric_context_path:
+        test_filter = "test_name:metric_context_path"
+        used_key = testcases_metric_context_path_setname
+
+    tags_regex_string = re.compile(args.testname_regex)
+    if args.test != "":
+        test_names = args.test.split(",")
+        logging.info("Using test name {}".format(test_names))
+    else:
+        try:
+            test_names = rts.smembers(used_key)
+            test_names = list(test_names)
+            test_names.sort()
+            final_test_names = []
+            for test_name in test_names:
+                test_name = test_name.decode()
+                match_obj = re.search(tags_regex_string, test_name)
+                if match_obj is not None:
+                    final_test_names.append(test_name)
+            test_names = final_test_names
+
+        except redis.exceptions.ResponseError as e:
+            logging.warning(
+                "Error while trying to fetch test cases set (key={}) {}. ".format(
+                    used_key, e.__str__()
+                )
+            )
+            pass
+
         logging.warning(
-            "Error while trying to fetch test cases set (key={}) {}. ".format(
-                testcases_setname, e.__str__()
+            "Based on test-cases set (key={}) we have {} comparison points. ".format(
+                used_key, len(test_names)
             )
         )
-        pass
-
-    logging.warning(
-        "Based on test-cases set (key={}) we have {} distinct benchmarks. ".format(
-            testcases_setname, len(test_names)
-        )
-    )
     profilers_artifacts_matrix = []
     detected_regressions = []
     total_improvements = 0
     total_stable = 0
     total_unstable = 0
     total_regressions = 0
+    noise_waterline = 2.5
+    progress = tqdm(unit="benchmark time-series", total=len(test_names))
     for test_name in test_names:
+        filters_baseline = [
+            "{}={}".format(by_str, baseline_str),
+            "metric={}".format(metric_name),
+            "{}={}".format(test_filter, test_name),
+            "deployment_name={}".format(baseline_deployment_name),
+            "triggering_env={}".format(tf_triggering_env),
+        ]
+        filters_comparison = [
+            "{}={}".format(by_str, comparison_str),
+            "metric={}".format(metric_name),
+            "{}={}".format(test_filter, test_name),
+            "deployment_name={}".format(comparison_deployment_name),
+            "triggering_env={}".format(tf_triggering_env),
+        ]
+        baseline_timeseries = rts.ts().queryindex(filters_baseline)
+        comparison_timeseries = rts.ts().queryindex(filters_comparison)
+
+        # avoiding target time-series
+        comparison_timeseries = [x for x in comparison_timeseries if "target" not in x]
+        baseline_timeseries = [x for x in baseline_timeseries if "target" not in x]
+        progress.update()
+        if args.verbose:
+            logging.info("Baseline timeseries {}".format(len(baseline_timeseries)))
+            logging.info("Comparison timeseries {}".format(len(comparison_timeseries)))
+        if len(baseline_timeseries) != 1:
+            if args.verbose:
+                logging.warning(
+                    "Skipping this test given the value of timeseries !=1. Baseline timeseries {}".format(
+                        len(baseline_timeseries)
+                    )
+                )
+            continue
+        else:
+            ts_name_baseline = baseline_timeseries[0]
+        if len(comparison_timeseries) != 1:
+            if args.verbose:
+                logging.warning(
+                    "Comparison timeseries {}".format(len(comparison_timeseries))
+                )
+            continue
+        else:
+            ts_name_comparison = comparison_timeseries[0]
 
-        test_name = test_name.decode()
-        ts_name_baseline = get_ts_metric_name(
-            "by.{}".format(by_str),
-            baseline_str,
-            tf_github_org,
-            tf_github_repo,
-            deployment_name,
-            deployment_type,
-            test_name,
-            tf_triggering_env,
-            metric_name,
-        )
-        ts_name_comparison = get_ts_metric_name(
-            "by.{}".format(by_str),
-            comparison_str,
-            tf_github_org,
-            tf_github_repo,
-            deployment_name,
-            deployment_type,
-            test_name,
-            tf_triggering_env,
-            metric_name,
-        )
         baseline_v = "N/A"
         comparison_v = "N/A"
         baseline_nsamples = 0
@@ -175,7 +227,9 @@ def compare_command_logic(args, project_name, project_version):
 
         note = ""
         try:
-            baseline_datapoints = rts.revrange(ts_name_baseline, from_ts_ms, to_ts_ms)
+            baseline_datapoints = rts.ts().revrange(
+                ts_name_baseline, from_ts_ms, to_ts_ms
+            )
             baseline_nsamples = len(baseline_datapoints)
             if baseline_nsamples > 0:
                 _, baseline_v = baseline_datapoints[0]
@@ -188,7 +242,7 @@ def compare_command_logic(args, project_name, project_version):
                 baseline_pct_change = (baseline_std / baseline_median) * 100.0
                 largest_variance = baseline_pct_change
 
-            comparison_datapoints = rts.revrange(
+            comparison_datapoints = rts.ts().revrange(
                 ts_name_comparison, from_ts_ms, to_ts_ms
             )
             comparison_nsamples = len(comparison_datapoints)
@@ -220,14 +274,14 @@ def compare_command_logic(args, project_name, project_version):
                 unstable = True
             if baseline_pct_change > 10.0:
                 stamp_b = "UNSTABLE"
-            baseline_v_str = " {:.3f} +- {:.1f}% {}".format(
-                baseline_v, baseline_pct_change, stamp_b
+            baseline_v_str = " {:.0f} +- {:.1f}% {} ({} datapoints)".format(
+                baseline_v, baseline_pct_change, stamp_b, baseline_nsamples
             )
             stamp_c = ""
             if comparison_pct_change > 10.0:
                 stamp_c = "UNSTABLE"
-            comparison_v_str = " {:.3f} +- {:.1f}% {}".format(
-                comparison_v, comparison_pct_change, stamp_c
+            comparison_v_str = " {:.0f} +- {:.1f}% {} ({} datapoints)".format(
+                comparison_v, comparison_pct_change, stamp_c, comparison_nsamples
             )
             if metric_mode == "higher-better":
                 percentage_change = (
@@ -247,16 +301,20 @@ def compare_command_logic(args, project_name, project_version):
                     detected_regression = True
                     total_regressions = total_regressions + 1
                     note = note + " REGRESSION"
-                else:
+                elif percentage_change < -noise_waterline:
                     note = note + " potential REGRESSION"
+                else:
+                    note = note + " -- no change --"
                 detected_regressions.append(test_name)
             if percentage_change > 0.0 and not unstable:
                 if percentage_change > waterline:
                     detected_improvement = True
                     total_improvements = total_improvements + 1
                     note = note + " IMPROVEMENT"
-                else:
+                elif percentage_change > noise_waterline:
                     note = note + " potential IMPROVEMENT"
+                else:
+                    note = note + " -- no change --"
 
             if (
                 detected_improvement is False
@@ -282,17 +340,18 @@ def compare_command_logic(args, project_name, project_version):
 
     logging.info("Printing differential analysis between branches")
     writer = MarkdownTableWriter(
-        table_name="Comparison between {} and {} for metric: {}. Time Period from {} to {}".format(
+        table_name="Comparison between {} and {} for metric: {}. Time Period from {} to {}. (environment used: {})".format(
             baseline_branch,
             comparison_branch,
             metric_name,
             from_human_str,
             to_human_str,
+            baseline_deployment_name,
         ),
         headers=[
             "Test Case",
-            "Baseline (median obs. +- std.dev)",
-            "Comparison (median obs. +- std.dev)",
+            "Baseline {} (median obs. +- std.dev)".format(baseline_branch),
+            "Comparison {} (median obs. +- std.dev)".format(comparison_branch),
             "% change ({})".format(metric_mode),
             "Note",
         ],
