@@ -5,10 +5,13 @@
 #
 import datetime
 import logging
+import threading
 
+import redisbench_admin
 from redisbench_admin.run.common import (
     prepare_benchmark_parameters,
 )
+from redisbench_admin.run.metrics import collect_cpu_data
 from redisbench_admin.run.run import calculate_client_tool_duration_and_check
 from redisbench_admin.run_remote.remote_helpers import (
     benchmark_tools_sanity_check,
@@ -46,6 +49,8 @@ def run_remote_client_tool(
     warn_min_duration,
     client_ssh_port,
     private_key,
+    collect_cpu_stats_thread=False,
+    redis_conns=[],
 ):
     (
         benchmark_min_tool_version,
@@ -105,6 +110,7 @@ def run_remote_client_tool(
         tmp = local_bench_fname
         local_bench_fname = "result.csv"
     commands = [command_str]
+    post_commands = []
     if "ann" in benchmark_tool:
         pkg_path = get_ann_remote_pkg_path(
             client_public_ip, client_ssh_port, private_key, username
@@ -120,10 +126,8 @@ def run_remote_client_tool(
         results_outputdir_zip_local = "results-{}.zip".format(benchmark_suffix)
 
         mkdir_command = "mkdir -p /tmp/{}".format(website_outputdir)
-        create_website_command = (
-            "cd {} && sudo python3 create_website.py --outputdir /tmp/{}".format(
-                create_website_path, website_outputdir
-            )
+        create_website_command = "cd {} && sudo python3 create_website.py --scatter --outputdir /tmp/{}".format(
+            create_website_path, website_outputdir
         )
         zip_website_command = "cd /tmp && zip -r {} {}/*".format(
             website_outputdir_zip, website_outputdir
@@ -132,15 +136,25 @@ def run_remote_client_tool(
         zip_results_command = "cd {} && zip -r {} results/*".format(
             results_outputdir, results_outputdir_zip
         )
-        commands.append(mkdir_command)
-        commands.append(create_website_command)
-        commands.append(zip_website_command)
-        commands.append(zip_results_command)
+        post_commands.append(mkdir_command)
+        post_commands.append(create_website_command)
+        post_commands.append(zip_website_command)
+        post_commands.append(zip_results_command)
 
         local_output_artifacts.append(website_outputdir_zip_local)
         local_output_artifacts.append(results_outputdir_zip_local)
         remote_output_artifacts.append(website_outputdir_zip)
         remote_output_artifacts.append(results_outputdir_zip)
+    cpu_stats_thread = None
+    if collect_cpu_stats_thread is True:
+        # run the benchmark
+        cpu_stats_thread = threading.Thread(
+            target=collect_cpu_data,
+            args=(redis_conns, 5.0, 1.0),
+        )
+        redisbench_admin.run.metrics.BENCHMARK_RUNNING_GLOBAL = True
+        logging.info("Starting CPU collecing thread")
+        cpu_stats_thread.start()
 
     benchmark_start_time = datetime.datetime.now()
     # run the benchmark
@@ -154,6 +168,32 @@ def run_remote_client_tool(
         client_ssh_port,
     )
     benchmark_end_time = datetime.datetime.now()
+    if cpu_stats_thread is not None:
+        logging.info("Stopping CPU collecting thread")
+        redisbench_admin.run.metrics.BENCHMARK_RUNNING_GLOBAL = False
+        cpu_stats_thread.join()
+        logging.info("CPU collecting thread stopped")
+    if len(post_commands) > 0:
+        res = execute_remote_commands(
+            client_public_ip, username, private_key, post_commands, client_ssh_port
+        )
+        recv_exit_status, _, _ = res[0]
+
+        if recv_exit_status != 0:
+            logging.error(
+                "Exit status of remote command execution {}. Printing stdout and stderr".format(
+                    recv_exit_status
+                )
+            )
+            stderr, stdout = print_commands_outputs(post_commands, True, res)
+        else:
+            logging.info(
+                "Remote process exited normally. Exit code {}. Printing stdout.".format(
+                    recv_exit_status
+                )
+            )
+            stderr, stdout = print_commands_outputs(post_commands, False, res)
+
     benchmark_duration_seconds = calculate_client_tool_duration_and_check(
         benchmark_end_time, benchmark_start_time, step_name, warn_min_duration
     )
@@ -183,7 +223,7 @@ def run_remote_client_tool(
         )
         command = ["cat {}".format(remote_results_file)]
         recv_exit_status, stdout, stderr = execute_remote_commands(
-            client_public_ip, username, private_key, [command], client_ssh_port
+            client_public_ip, username, private_key, command, client_ssh_port
         )[0]
         logging.warning("Remote results file content: {}".format(stdout))
 
@@ -224,15 +264,15 @@ def run_remote_client_tool(
 def setup_remote_benchmark_ann(
     client_public_ip, username, private_key, client_ssh_port
 ):
-    commands = [
-        "sudo apt install python3-pip -y",
-        "sudo pip3 install redisbench-admin>=0.7.0",
-    ]
-    # last argument (get_pty) needs to be set to true
-    # check: https://stackoverflow.com/questions/5785353/paramiko-and-sudo
-    execute_remote_commands(
-        client_public_ip, username, private_key, commands, client_ssh_port, True
-    )
+    # commands = [
+    #     "sudo apt install python3-pip -y",
+    #     "sudo pip3 install redisbench-admin>=0.7.0",
+    # ]
+    # # last argument (get_pty) needs to be set to true
+    # # check: https://stackoverflow.com/questions/5785353/paramiko-and-sudo
+    # execute_remote_commands(
+    #     client_public_ip, username, private_key, commands, client_ssh_port, True
+    # )
     pkg_path = get_ann_remote_pkg_path(
         client_public_ip, client_ssh_port, private_key, username
     )
