@@ -11,8 +11,12 @@ import traceback
 import redis
 import pytablewriter
 from pytablewriter import MarkdownTableWriter
-
-
+import redisbench_admin.run.metrics
+from redisbench_admin.profilers.perf import PERF_CALLGRAPH_MODE
+from redisbench_admin.run.metrics import (
+    from_info_to_overall_shard_cpu,
+    collect_redis_metrics,
+)
 from redisbench_admin.profilers.perf_daemon_caller import (
     PerfDaemonRemoteCaller,
     PERF_DAEMON_LOGNAME,
@@ -27,7 +31,6 @@ from redisbench_admin.run.common import (
 )
 from redisbench_admin.run.git import git_vars_crosscheck
 from redisbench_admin.run.grafana import generate_artifacts_table_grafana_redis
-from redisbench_admin.run.metrics import collect_redis_metrics
 from redisbench_admin.run.modules import redis_modules_check
 from redisbench_admin.run.redistimeseries import (
     timeseries_test_sucess_flow,
@@ -36,6 +39,7 @@ from redisbench_admin.run.redistimeseries import (
 from redisbench_admin.run.run import define_benchmark_plan
 from redisbench_admin.run.s3 import get_test_s3_bucket_path
 from redisbench_admin.run.ssh import ssh_pem_check
+from redisbench_admin.run_remote.args import TF_OVERRIDE_NAME
 from redisbench_admin.run_remote.consts import min_recommended_benchmark_duration
 from redisbench_admin.run_remote.remote_client import run_remote_client_tool
 from redisbench_admin.run_remote.remote_db import (
@@ -152,6 +156,7 @@ def run_remote_command_logic(args, project_name, project_version):
     remote_envs = {}
     dirname = "."
     (
+        _,
         _,
         _,
         tsname_project_total_failures,
@@ -208,13 +213,34 @@ def run_remote_command_logic(args, project_name, project_version):
     overall_tables = {}
 
     for benchmark_type, bench_by_dataset_map in benchmark_runs_plan.items():
+        if return_code != 0 and args.fail_fast:
+            logging.warning(
+                "Given you've selected fail fast skipping benchmark_type {}".format(
+                    benchmark_type
+                )
+            )
+            continue
         logging.info("Running benchmarks of type {}.".format(benchmark_type))
         for (
             dataset_name,
             bench_by_dataset_and_setup_map,
         ) in bench_by_dataset_map.items():
+            if return_code != 0 and args.fail_fast:
+                logging.warning(
+                    "Given you've selected fail fast skipping dataset {}".format(
+                        dataset_name
+                    )
+                )
+                continue
             logging.info("Running benchmarks for dataset {}.".format(dataset_name))
             for setup_name, setup_details in bench_by_dataset_and_setup_map.items():
+                if return_code != 0 and args.fail_fast:
+                    logging.warning(
+                        "Given you've selected fail fast skipping setup {}".format(
+                            setup_name
+                        )
+                    )
+                    continue
 
                 setup_settings = setup_details["setup_settings"]
                 benchmarks_map = setup_details["benchmarks"]
@@ -225,6 +251,13 @@ def run_remote_command_logic(args, project_name, project_version):
                 overall_tables[setup_name] = {}
 
                 for test_name, benchmark_config in benchmarks_map.items():
+                    if return_code != 0 and args.fail_fast:
+                        logging.warning(
+                            "Given you've selected fail fast skipping test {}".format(
+                                test_name
+                            )
+                        )
+                        continue
                     metadata_tags = get_metadata_tags(benchmark_config)
                     logging.info(
                         "Including the extra metadata tags into this test generated time-series: {}".format(
@@ -232,6 +265,13 @@ def run_remote_command_logic(args, project_name, project_version):
                         )
                     )
                     for repetition in range(1, BENCHMARK_REPETITIONS + 1):
+                        if return_code != 0 and args.fail_fast:
+                            logging.warning(
+                                "Given you've selected fail fast skipping repetition {}".format(
+                                    repetition
+                                )
+                            )
+                            continue
                         remote_perf = None
                         logging.info(
                             "Repetition {} of {}. Running test {}".format(
@@ -292,6 +332,7 @@ def run_remote_command_logic(args, project_name, project_version):
                                     tf_setup_name_sufix,
                                     tf_triggering_env,
                                     tf_timeout_secs,
+                                    TF_OVERRIDE_NAME,
                                 )
 
                                 # after we've created the env, even on error we should always teardown
@@ -448,13 +489,16 @@ def run_remote_command_logic(args, project_name, project_version):
                                         ]
                                         start_profile_result = (
                                             remote_perf.start_profile(
-                                                primary_one_pid, "", PROFILE_FREQ
+                                                primary_one_pid,
+                                                "",
+                                                PROFILE_FREQ,
+                                                PERF_CALLGRAPH_MODE,
                                             )
                                         )
                                         if start_profile_result is True:
                                             logging.info(
-                                                "Successfully started remote profile for Redis with PID: {}".format(
-                                                    primary_one_pid
+                                                "Successfully started remote profile for Redis with PID: {}. Used call-graph mode {}".format(
+                                                    primary_one_pid, PERF_CALLGRAPH_MODE
                                                 )
                                             )
 
@@ -493,6 +537,8 @@ def run_remote_command_logic(args, project_name, project_version):
                                         min_recommended_benchmark_duration,
                                         client_ssh_port,
                                         private_key,
+                                        True,
+                                        redis_conns,
                                     )
 
                                     if profilers_enabled:
@@ -556,6 +602,24 @@ def run_remote_command_logic(args, project_name, project_version):
                                                 )
                                             )
 
+                                    (
+                                        total_shards_cpu_usage,
+                                        cpu_usage_map,
+                                    ) = from_info_to_overall_shard_cpu(
+                                        redisbench_admin.run.metrics.BENCHMARK_CPU_STATS_GLOBAL
+                                    )
+                                    if total_shards_cpu_usage is None:
+                                        total_shards_cpu_usage_str = "n/a"
+                                    else:
+                                        total_shards_cpu_usage_str = "{:.3f}".format(
+                                            total_shards_cpu_usage
+                                        )
+                                    logging.info(
+                                        "Total CPU usage ({} %)".format(
+                                            total_shards_cpu_usage_str
+                                        )
+                                    )
+
                                     if remote_run_result is False:
                                         db_error_artifacts(
                                             db_ssh_port,
@@ -594,6 +658,10 @@ def run_remote_command_logic(args, project_name, project_version):
                                                     ]
                                                 },
                                             )
+                                            if total_shards_cpu_usage is not None:
+                                                overall_end_time_metrics[
+                                                    "total_shards_used_cpu_pct"
+                                                ] = total_shards_cpu_usage
                                             expire_ms = 7 * 24 * 60 * 60 * 1000
                                             export_redis_metrics(
                                                 artifact_version,
@@ -739,6 +807,7 @@ def run_remote_command_logic(args, project_name, project_version):
                                             results_dict,
                                             setup_name,
                                             test_name,
+                                            total_shards_cpu_usage,
                                         )
                                     client_artifacts.append(local_bench_fname)
                                     client_artifacts.extend(client_output_artifacts)
