@@ -37,7 +37,17 @@ def spin_up_standalone_remote_redis(
 
     # start redis-server
     commands = [initial_redis_cmd]
-    execute_remote_commands(server_public_ip, username, private_key, commands, port)
+    res = execute_remote_commands(
+        server_public_ip, username, private_key, commands, port
+    )
+    for pos, res_pos in enumerate(res):
+        [recv_exit_status, stdout, stderr] = res_pos
+        if recv_exit_status != 0:
+            logging.error(
+                "Remote primary shard {} command returned exit code {}. stdout {}. stderr {}".format(
+                    pos, recv_exit_status, stdout, stderr
+                )
+            )
     return full_logfile
 
 
@@ -96,7 +106,7 @@ def generate_remote_standalone_redis_cmd(
     temporary_dir,
     modules_configuration_parameters_map,
 ):
-    initial_redis_cmd = 'redis-server --save "" --logfile {} --dir {} --daemonize yes --protected-mode no'.format(
+    initial_redis_cmd = "redis-server --save '' --logfile {} --dir {} --daemonize yes --protected-mode no".format(
         logfile, temporary_dir
     )
     full_logfile = "{}/{}".format(temporary_dir, logfile)
